@@ -1,6 +1,6 @@
 package BankAccount::Validator::UK;
 
-$BankAccount::Validator::UK::VERSION   = '0.63';
+$BankAccount::Validator::UK::VERSION   = '0.64';
 $BankAccount::Validator::UK::AUTHORITY = 'cpan:MANWAR';
 
 =head1 NAME
@@ -9,7 +9,7 @@ BankAccount::Validator::UK - Interface to validate UK bank account.
 
 =head1 VERSION
 
-Version 0.63
+Version 0.64
 
 =cut
 
@@ -36,7 +36,7 @@ has sort_code  => (is => 'ro', default => sub { BankAccount::Validator::UK::Rule
 The module uses the algorithm provided by VOCALINK to validate the bank sort code
 and account number.  It is  done by modulus  checking  method as specified in the
 document which is available on their website L<VOCALINK|https://www.vocalink.com/tools/modulus-checking/>
-It currently supports the document L<v7.10|https://www.vocalink.com/media/2vtny3ie/validating-account-numbers-v7-1.pdf> drafted 3rd Mar 2022.
+It currently supports the document L<v7.20|https://www.vocalink.com/media/y3nfvmjy/validating-account-numbers-v7-2.pdf> drafted 31st May 2022.
 
 Institutions covered by this document are below:
 
